@@ -1,4 +1,4 @@
-"""
+'''
 # Targets for AWS Elastic Load Balancing V2
 
 <!--BEGIN STABILITY BANNER-->---
@@ -16,7 +16,7 @@
 <!--END STABILITY BANNER-->
 
 This package contains targets for ELBv2. See the README of the `@aws-cdk/aws-elasticloadbalancingv2` library.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -39,26 +39,26 @@ class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceIdTarget",
 ):
-    """(experimental) An EC2 instance that is the target for load balancing.
+    '''(experimental) An EC2 instance that is the target for load balancing.
 
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can connect to the instance.
 
     :stability: experimental
-    """
+    '''
 
     def __init__(
         self,
         instance_id: builtins.str,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """(experimental) Create a new Instance target.
+        '''(experimental) Create a new Instance target.
 
         :param instance_id: Instance ID of the instance to register to.
         :param port: Override the default port for the target group.
 
         :stability: experimental
-        """
+        '''
         jsii.create(InstanceIdTarget, self, [instance_id, port])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
@@ -66,7 +66,7 @@ class InstanceIdTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """(experimental) Register this instance target with a load balancer.
+        '''(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
@@ -74,15 +74,15 @@ class InstanceIdTarget(
         :param target_group: -
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
+        '''
+        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """(experimental) Register this instance target with a load balancer.
+        '''(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
@@ -90,8 +90,8 @@ class InstanceIdTarget(
         :param target_group: -
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
+        '''
+        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
 class InstanceTarget(
@@ -99,22 +99,22 @@ class InstanceTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceTarget",
 ):
-    """
+    '''
     :stability: experimental
-    """
+    '''
 
     def __init__(
         self,
         instance: aws_cdk.aws_ec2.Instance,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """(experimental) Create a new Instance target.
+        '''(experimental) Create a new Instance target.
 
         :param instance: Instance to register to.
         :param port: Override the default port for the target group.
 
         :stability: experimental
-        """
+        '''
         jsii.create(InstanceTarget, self, [instance, port])
 
 
@@ -123,7 +123,7 @@ class IpTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.IpTarget",
 ):
-    """(experimental) An IP address that is a target for load balancing.
+    '''(experimental) An IP address that is a target for load balancing.
 
     Specify IP addresses from the subnets of the virtual private cloud (VPC) for
     the target group, the RFC 1918 range (10.0.0.0/8, 172.16.0.0/12, and
@@ -134,7 +134,7 @@ class IpTarget(
     sure the load balancer's security group can send packets to the IP address.
 
     :stability: experimental
-    """
+    '''
 
     def __init__(
         self,
@@ -142,7 +142,7 @@ class IpTarget(
         port: typing.Optional[jsii.Number] = None,
         availability_zone: typing.Optional[builtins.str] = None,
     ) -> None:
-        """(experimental) Create a new IPAddress target.
+        '''(experimental) Create a new IPAddress target.
 
         The availabilityZone parameter determines whether the target receives
         traffic from the load balancer nodes in the specified Availability Zone
@@ -164,7 +164,7 @@ class IpTarget(
         :param availability_zone: Availability zone to send traffic from.
 
         :stability: experimental
-        """
+        '''
         jsii.create(IpTarget, self, [ip_address, port, availability_zone])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
@@ -172,7 +172,7 @@ class IpTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """(experimental) Register this instance target with a load balancer.
+        '''(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
@@ -180,15 +180,15 @@ class IpTarget(
         :param target_group: -
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
+        '''
+        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """(experimental) Register this instance target with a load balancer.
+        '''(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
@@ -196,8 +196,8 @@ class IpTarget(
         :param target_group: -
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
+        '''
+        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
 @jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget)
@@ -205,17 +205,17 @@ class LambdaTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.LambdaTarget",
 ):
-    """
+    '''
     :stability: experimental
-    """
+    '''
 
     def __init__(self, fn: aws_cdk.aws_lambda.IFunction) -> None:
-        """(experimental) Create a new Lambda target.
+        '''(experimental) Create a new Lambda target.
 
         :param fn: -
 
         :stability: experimental
-        """
+        '''
         jsii.create(LambdaTarget, self, [fn])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
@@ -223,7 +223,7 @@ class LambdaTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """(experimental) Register this instance target with a load balancer.
+        '''(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
@@ -231,15 +231,15 @@ class LambdaTarget(
         :param target_group: -
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "attachToApplicationTargetGroup", [target_group])
+        '''
+        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
     @jsii.member(jsii_name="attachToNetworkTargetGroup")
     def attach_to_network_target_group(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        """(experimental) Register this instance target with a load balancer.
+        '''(experimental) Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
@@ -247,8 +247,8 @@ class LambdaTarget(
         :param target_group: -
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "attachToNetworkTargetGroup", [target_group])
+        '''
+        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
 
 __all__ = [
